# Direct and Alternating Currents

The magnitude and direction of current from a drycell does not change with time. It is called DC or dirrect current. The mains supply we get is of different kind. The mains supply in India is 230V at 50 Hz. A frequency of 50 Hz means the change in voltage repeats every 20 milliseconds. If we measure the voltage across the phase and neutral terminals of a household power socket, the voltage will increase from zero to 325V (230√(2)) in 5 mS and it will be back to zero in the next 5 mS. During the third 5mS it will reach -325V and will again reach zero during the fourth 5mS. These type of current is called alternating current (AC). To study the behavior of AC, an oscilloscope is required.

# Objective

Introduce the concept of time dependent voltages, using a V(t) graph. Compare the graph of DC and AC.

# Procedure

- Connect WG to A1 and PV1 to A2, using wires.
- Set PV1 to 2 volts and Set WG to 1000 Hz
- Enable analyse on A1, to measure amplitude and frequency.
- Enable A2

The observed results are shown here.

This should not lead to a conclusion the voltages are either DC or AC. There could be combination of both. For example, take the case of a squarewave that changes between 0 and 5V.

- Connect SQ1 to A1
- Set range of A1 to 8V. Adjust trigger a bit for a stable trace.
- Set PV1 to 2 volts and Set WG to 1000 Hz

Is the graph shown below is AC or DC ? It is a 2.5 DC plus an AC changing from -2.5V to +2.5V. Separating these components will be explained in the coming sections.

If the voltage is not changing with time, it is pure DC. If it is changing with time, it has an AC component. if the average voltage is zero, it is pure AC.